/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eos.notification.control
{
import com.adobe.cairngorm.control.CairngormEventDispatcher;
import com.adobe.cairngorm.control.FrontController;

import org.ow2.jasmine.monitoring.eos.notification.command.*;
import org.ow2.jasmine.monitoring.eos.notification.event.*;
import org.ow2.jasmine.monitoring.eos.notification.model.*;


/**
 * Bind a type of command to an action.
 * @author radua
 */
public class Controller extends FrontController {

    /**
     * Create an instance of the controller. Commands are initialized here.
     */
    public function Controller(dispatcher: CairngormEventDispatcher) { 
        super(dispatcher);
    }

    /**
    * Add all the commands to the pool of commands.
    *
    * An unique ID was added to all the events in order
    * to prevent a Cairngorm issue: when a command event is dispatched,
    * every controller that registered this event type receives it, even if
    * located in another module. To prevent this from happening and triggering
    * multiple severe unexpected concurrence bugs, each event dispatched is
    * postfixed with this unique ID.
    */

    public function initialiseCommands() : void {
        this.addCommand(NotifEvent.GET_JASMINE_NOTIFS_DB, GetJasmineNotifsCommand);
        this.addCommand(NotifEvent.GET_JASMINE_NOTIFS_JMS, GetJasmineNotifsJMSCommand);
        this.addCommand(NotifEvent.GET_JASMINE_NOTIFS_DB_FROM_TO, GetJasmineNotifsFromToCommand);
        this.addCommand(GetActionsEvent.GET_ACTIONS, GetNotificationSettingsCommand);
        this.addCommand(ExecuteActionEvent.EXECUTE_ACTION, ExecuteActionCommand);
        this.addCommand(CheckNotificationStateEvent.CHECK_NOTIFICATION_STATE, CheckNotificationStateCommand);
        this.addCommand(GetLoggedUserEvent.GET_CURRENT_LOGGED_USER, GetLoggedUserCommand);
    }

    public function removeCommands(): void {
        this.removeCommand(NotifEvent.GET_JASMINE_NOTIFS_DB);
        this.removeCommand(NotifEvent.GET_JASMINE_NOTIFS_JMS);
        this.removeCommand(NotifEvent.GET_JASMINE_NOTIFS_DB_FROM_TO);
        this.removeCommand(GetActionsEvent.GET_ACTIONS);
        this.removeCommand(ExecuteActionEvent.EXECUTE_ACTION);
        this.removeCommand(CheckNotificationStateEvent.CHECK_NOTIFICATION_STATE);
        this.removeCommand(GetLoggedUserEvent.GET_CURRENT_LOGGED_USER);
    }

}
}
